##  Record Architecture Decisions
Architecture decisions serve two purposes: they act as a historical record for future reference and governance, and they support strategic alignment in decision-making. This makes them especially useful during proposal evaluations conducted by architecture review boards. To simplify documenting, tracking, and managing these decisions, you can create and store the architecture decision records associated with your modernization directly in SAP LeanIX.
To record your decisions, follow these steps:
  1. Go to More > Architecture Decisions.
  2. Select New Decision and select a template. The default template is Architecture Decision.
Learn more about architecture decisions in [Architecture Decisions](https://help.sap.com/docs/leanix/ea/architecture-decisions?locale=en-US&state=PRODUCTION&version=CLOUD "Document and manage enterprise architecture decisions directly within SAP LeanIX, keeping all architecture-related information in one place.").
  3. Fill in the relevant details and select a status for this decision.
You can also come back to a decision and change details later.
Example of an Architecture Decision for Modernization
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio0373a157576a45a18077e7a948255a88_LowRes.png)


Once you've documented all 6R classification decisions for your applications, revisit your target KPIs. By comparing the current state and target state of the hosting type, you gain visibility into your modernization journey and can make adjustments as needed.
YesNo
Send
![close icon](https://consent.trustarc.com/get?name=sapglow-close-icon.png)
This site uses cookies and related technologies, as described in our Cookie Statement, for purposes that may include site operation, analytics, enhanced user experience, or advertising. You may choose to consent to our use of these technologies, or manage your own preferences.
Understood Manage Settings
[Privacy Statement](https://help.sap.com/docs/privacy)|[Cookie Statement](https://www.sap.com/about/legal/privacy/cookies.html)
